@@ -23,7 +23,7 @@ func NewCommitCommands(gitCommon *GitCommon) *CommitCommands {
 // ResetAuthor resets the author of the topmost commit
 func (self *CommitCommands) ResetAuthor() error {
 	cmdArgs := NewGitCmd("commit").
-		Arg("--allow-empty", "--only", "--no-edit", "--amend", "--reset-author").
+		Arg("--allow-empty", "--allow-empty-message", "--only", "--no-edit", "--amend", "--reset-author").
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
@@ -32,7 +32,7 @@ func (self *CommitCommands) ResetAuthor() error {
 // Sets the commit's author to the supplied value. Value is expected to be of the form 'Name <Email>'
 func (self *CommitCommands) SetAuthor(value string) error {
 	cmdArgs := NewGitCmd("commit").
-		Arg("--allow-empty", "--only", "--no-edit", "--amend", "--author="+value).
+		Arg("--allow-empty", "--allow-empty-message", "--only", "--no-edit", "--amend", "--author="+value).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
@@ -149,9 +149,8 @@ func (self *CommitCommands) CommitEditorCmdObj() *oscommands.CmdObj {
 func (self *CommitCommands) signoffFlag() string {
 	if self.UserConfig().Git.Commit.SignOff {
 		return "--signoff"
-	} else {
-		return ""
 	}
+	return ""
 }
 
 func (self *CommitCommands) GetCommitMessage(commitHash string) (string, error) {
@@ -248,14 +247,14 @@ func (self *CommitCommands) AmendHead() error {
 
 func (self *CommitCommands) AmendHeadCmdObj() *oscommands.CmdObj {
 	cmdArgs := NewGitCmd("commit").
-		Arg("--amend", "--no-edit", "--allow-empty").
+		Arg("--amend", "--no-edit", "--allow-empty", "--allow-empty-message").
 		ToArgv()
 
 	return self.cmd.New(cmdArgs)
 }
 
-func (self *CommitCommands) ShowCmdObj(hash string, filterPath string) *oscommands.CmdObj {
-	contextSize := self.AppState.DiffContextSize
+func (self *CommitCommands) ShowCmdObj(hash string, filterPaths []string) *oscommands.CmdObj {
+	contextSize := self.UserConfig().Git.DiffContextSize
 
 	extDiffCmd := self.UserConfig().Git.Paging.ExternalDiffCommand
 	cmdArgs := NewGitCmd("show").
@@ -269,9 +268,10 @@ func (self *CommitCommands) ShowCmdObj(hash string, filterPath string) *oscomman
 		Arg("--decorate").
 		Arg("-p").
 		Arg(hash).
-		ArgIf(self.AppState.IgnoreWhitespaceInDiffView, "--ignore-all-space").
-		Arg(fmt.Sprintf("--find-renames=%d%%", self.AppState.RenameSimilarityThreshold)).
-		ArgIf(filterPath != "", "--", filterPath).
+		ArgIf(self.UserConfig().Git.IgnoreWhitespaceInDiffView, "--ignore-all-space").
+		Arg(fmt.Sprintf("--find-renames=%d%%", self.UserConfig().Git.RenameSimilarityThreshold)).
+		Arg("--").
+		Arg(filterPaths...).
 		Dir(self.repoPaths.worktreePath).
 		ToArgv()
 
