@@ -29,7 +29,7 @@ type IGuiCommon interface {
 	LogAction(action string)
 	LogCommand(cmdStr string, isCommandLine bool)
 	// we call this when we want to refetch some models and render the result. Internally calls PostRefreshUpdate
-	Refresh(RefreshOptions) error
+	Refresh(RefreshOptions)
 	// we call this when we've changed something in the view model but not the actual model,
 	// e.g. expanding or collapsing a folder in a file view. Calling 'Refresh' in this
 	// case would be overkill, although refresh will internally call 'PostRefreshUpdate'
@@ -94,7 +94,7 @@ type IGuiCommon interface {
 
 	Modes() *Modes
 
-	Mutexes() Mutexes
+	Mutexes() *Mutexes
 
 	State() IStateAccessor
 
@@ -126,6 +126,8 @@ type IPopupHandler interface {
 	Alert(title string, message string)
 	// Shows a popup asking the user for confirmation.
 	Confirm(opts ConfirmOpts)
+	// Shows a popup asking the user for confirmation if condition is true; otherwise, the HandleConfirm function is called directly.
+	ConfirmIf(condition bool, opts ConfirmOpts) error
 	// Shows a popup prompting the user for input.
 	Prompt(opts PromptOpts)
 	WithWaitingStatus(message string, f func(gocui.Task) error) error
@@ -202,6 +204,10 @@ type DisabledReason struct {
 	// error panel instead. This is useful if the text is very long, or if it is
 	// important enough to show it more prominently, or both.
 	ShowErrorInPanel bool
+
+	// If true, the keybinding dispatch mechanism will continue to look for
+	// other handlers for the keypress.
+	AllowFurtherDispatching bool
 }
 
 type MenuWidget int
@@ -283,10 +289,11 @@ type Model struct {
 	Worktrees    []*models.Worktree
 
 	// FilteredReflogCommits are the ones that appear in the reflog panel.
-	// when in filtering mode we only include the ones that match the given path
+	// When in filtering mode we only include the ones that match the given path
 	FilteredReflogCommits []*models.Commit
-	// ReflogCommits are the ones used by the branches panel to obtain recency values
-	// if we're not in filtering mode, CommitFiles and FilteredReflogCommits will be
+	// ReflogCommits are the ones used by the branches panel to obtain recency values,
+	// and for the undo functionality.
+	// If we're not in filtering mode, CommitFiles and FilteredReflogCommits will be
 	// one and the same
 	ReflogCommits []*models.Commit
 
@@ -309,18 +316,16 @@ type Model struct {
 	HashPool *utils.StringPool
 }
 
-// if you add a new mutex here be sure to instantiate it. We're using pointers to
-// mutexes so that we can pass the mutexes to controllers.
 type Mutexes struct {
-	RefreshingFilesMutex    *deadlock.Mutex
-	RefreshingBranchesMutex *deadlock.Mutex
-	RefreshingStatusMutex   *deadlock.Mutex
-	LocalCommitsMutex       *deadlock.Mutex
-	SubCommitsMutex         *deadlock.Mutex
-	AuthorsMutex            *deadlock.Mutex
-	SubprocessMutex         *deadlock.Mutex
-	PopupMutex              *deadlock.Mutex
-	PtyMutex                *deadlock.Mutex
+	RefreshingFilesMutex    deadlock.Mutex
+	RefreshingBranchesMutex deadlock.Mutex
+	RefreshingStatusMutex   deadlock.Mutex
+	LocalCommitsMutex       deadlock.Mutex
+	SubCommitsMutex         deadlock.Mutex
+	AuthorsMutex            deadlock.Mutex
+	SubprocessMutex         deadlock.Mutex
+	PopupMutex              deadlock.Mutex
+	PtyMutex                deadlock.Mutex
 }
 
 // A long-running operation associated with an item. For example, we'll show
